@@ -18,12 +18,13 @@ from typing import Any, Dict, List
 
 
 # Import from lupulib
-import lupulib.devices.alarm as ALARM
+import lupulib
+import lupulib.devices
 import lupulib.constants as CONST
-from lupulib.exceptions import LupusecParseError, LupusecRequestError, LupusecResponseError
-from lupulib.devices.binary_sensor import LupusecBinarySensor
-from lupulib.devices.switch import LupusecSwitch
-from lupulib.system import System
+# from lupulib.exceptions import LupusecParseError, LupusecRequestError, LupusecResponseError
+# from lupulib.devices.binary_sensor import LupusecBinarySensor
+# from lupulib.devices.switch import LupusecSwitch
+
 
 _LOGGER = logging.getLogger(__name__)
 home = str(Path.home())
@@ -33,7 +34,7 @@ class LupusecAPI:
     """Interface to Lupusec Webservices."""
 
     def __init__(self, username, password, ip_address) -> None:
-        """Lupsec constructor to interface Lupusec Alarm System."""
+        """LupusecAPI constructor to interface Lupusec Alarm System."""
         
         self._username = username
         self._password = password
@@ -44,6 +45,7 @@ class LupusecAPI:
         if _username != None and _password != None:
             self._auth = aiohttp.BasicAuth(login=_username, password=_password, encoding='utf-8')
         self._session = aiohttp.ClientSession(auth=_auth)
+        self._system = None
 
 
     async def _async_api_call(client, url):
@@ -61,7 +63,7 @@ class LupusecAPI:
             raise LupusecRequestError(str(exception)) from exception
 
 
-    async def async_get_system(self) -> System:
+    async def async_get_system(self) -> devices.system.LupusecSystem:
         """Async method to get the system info."""
         _LOGGER.debug("async_get_system() called: ")
 
@@ -74,11 +76,11 @@ class LupusecAPI:
         # Get System Info
         url_cmd = CONST.INFO_REQUEST
         async with _session as client:
-            data = await _async_api_call(client, url_cmd)   
+            data = await _async_api_call(client, url_cmd) 
     
         # try to parse json response
         try:
-            json_data = json.loads(system)["updates"]
+            json_data = json.loads(data)["updates"]
         except json.JSONDecodeError as exception:
             raise LupusecParseError(str(exception)) from exception
         
@@ -87,7 +89,7 @@ class LupusecAPI:
         print("  Firmware-Version: %s ", json_data["em_ver"])
 
         #return self.clean_json(response.text)[CONST.INFO_HEADER]
-        return System(json_data)
+        return devices.system.LupusecSystem(json_data)
  
 
     def _request_post(self, action, params={}):
@@ -245,7 +247,7 @@ class LupusecAPI:
             if alarmDevice:
                 alarmDevice.update(panelJson)
             else:
-                alarmDevice = ALARM.create_alarm(panelJson, self)
+                alarmDevice = devices.LupusecAlarm.create_alarm(panelJson, self)
                 self._devices["0"] = alarmDevice
 
             # Now we will handle the power switches
